@@ -27,6 +27,13 @@
 namespace KMime
 {
 
+/**
+ *  Consult the charset cache. Only used for reducing mem usage by
+ *  keeping strings in a common repository.
+ *  @param name
+ */
+extern QByteArray cachedCharset(const QByteArray &name);
+
 /**
   Finds the header end in @p src. Aligns the @p dataBegin if needed.
   @param dataBegin beginning of the data part of the header
@@ -45,17 +52,32 @@ extern int findHeaderLineEnd(const QByteArray &src, int &dataBegin, bool *folded
 extern int indexOfHeader(const QByteArray &src, const QByteArray &name, int &end, int &dataBegin, bool *folded = 0);
 
 /**
-  Removes the first occurrence of the @p name from @p head.
-*/
-// This is used in zero places at the moment.
-extern void removeHeader(QByteArray &head, const QByteArray &name);
-
-/**
- * Same as encodeRFC2047String(), but with a crucial difference: Instead of encoding the complete
- * string as a single encoded word, the string will be split up at control characters, and only parts of
- * the sentence that really need to be encoded will be encoded.
+ *  Uses current time, pid and random numbers to construct a string
+ *  that aims to be unique on a per-host basis (ie. for the local
+ *  part of a message-id or for multipart boundaries.
+ *
+ *  @return the unique string.
+ *  @see multiPartBoundary
  */
-extern QByteArray encodeRFC2047Sentence(const QString &src, const QByteArray &charset);
+extern QByteArray uniqueString();
+
+//@cond PRIVATE
+extern const uchar aTextMap[16];
+extern const uchar tTextMap[16];
+
+inline bool isOfSet(const uchar map[16], unsigned char ch)
+{
+    return (ch < 128) && (map[ ch / 8 ] & 0x80 >> ch % 8);
+}
+inline bool isAText(char ch)
+{
+    return isOfSet(aTextMap, ch);
+}
+inline bool isTText(char ch)
+{
+    return isOfSet(tTextMap, ch);
+}
+//@endcond
 
 }
 
